@@ -20,7 +20,8 @@ class Bobcat:
 
     def __init__(self,
                  miner_ip='',
-                 get_timeout=5,
+                 get_timeout=20,
+                 auto_connect=True
                  ):
         """Init the Bobcat object
 
@@ -28,11 +29,12 @@ class Bobcat:
         """
         self.miner_ip = miner_ip
         self.get_timeout = get_timeout
-        if self.ping() != 0:
+
+        if auto_connect and self.ping() != 0:
             print("[-] Miner not responding or not connected to the network")
 
     def ping(self):
-        # Verify connectivity
+        """Verify connectivity"""
         sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         return sock.connect_ex((self.miner_ip, 80))
 
@@ -74,7 +76,7 @@ class Bobcat:
 
     def blockchain_height(self):
         """Return the current Helium blockchain height"""
-        req = Request(f"https://api.helium.io/v1/blocks/height")
+        req = Request("https://api.helium.io/v1/blocks/height")
         height = self.__open(req)
         return height['data']['height']
 
